@@ -2256,6 +2256,9 @@ object. The corresponding values are the resulting sections of type
 
 :Parameters:
 
+    o: `Field` or `Data`
+        The `Field` or `Data` object to be sectioned.
+
     axes: *optional*
         In the case of a Field this is a query for the m axes that
         define the sections of the Field as accepted by the Field
@@ -2267,6 +2270,9 @@ object. The corresponding values are the resulting sections of type
         indices of the m axes that define the sections of the Data
         object. If axes is None (the default) all axes are selected.
     
+        Note: the axes specified by the *axes* parameter are the one
+        which are to be  kept whole. All other axes are sectioned
+
     data: `bool`, optional
         If True this indicates that a data object has been passed, if
         False it indicates that a field object has been passed. By
@@ -2333,14 +2339,20 @@ names:
         
         # Define the factor which, when multiplied by the size of the
         # data array, determines how many chunks are in the data array.
+        #
+        # I.e. factor = 1/(the number of words per chunk)
         factor = (o.dtype.itemsize + 1.0)/CHUNKSIZE()
 
         # n_chunks = number of equal sized bits the partition
         #            needs to be split up into so that each bit's
-        #            size is less than ther chunk size.
+        #            size is less than the chunk size.
         n_chunks = int(math_ceil(o.size*factor))
 
         for (index, axis_size) in enumerate(sizes):
+            if index in axis_indices:
+                # Do not attempt to "chunk" non-sectioned axes
+                continue
+
             if int(math_ceil(float(axis_size)/min_step)) <= n_chunks:
                 n_chunks = int(math_ceil(n_chunks/float(axis_size)*min_step))
                 steps[index] = min_step
@@ -2350,9 +2362,9 @@ names:
                 break
         #--- End: for
     else:
-        steps = [1] * len(sizes)
+        steps = [size if i in axis_indices else 1 for i, size in enumerate(sizes)]
     
-    # use recursion to slice out each 2D horizontal section
+    # use recursion to slice out each section
     if data:
         d = dict()
     else:
