@@ -1933,8 +1933,7 @@ created. The ``seen`` dictionary is updated for *cfvar*.
             chunksizes = None
 
         if _debug:
-            print 'chunksizes =', chunksizes
-#        print 'chunksizes =', cfvar, chunksizes
+            print '        chunksizes =', chunksizes
             
         try:
             g['nc'][ncvar] = g['netcdf'].createVariable(
@@ -2030,15 +2029,15 @@ message+"\nUnlimited dimension must be the first (leftmost) dimension of the var
                 #--- End: if
 
                 if _debug:
-                    print '            partition.indices =', partition.indices
-                    print '            array.shape       =', array.shape
-                    print '            array.max()       =', array.max()
+                    print '            partition.indices, array.shape =', partition.indices, array.shape
 
                 # Copy the array into the netCDF variable
                 g['nc'][ncvar][partition.indices] = array        
 
                 partition.close()
-            #--- End: for                  
+            #--- End: for
+            if _debug:
+                print '        Finished writing '+repr(cfvar)+' netCDF: '+ncvar
         #--- End: if
 
         # Update the 'seen' dictionary
