@@ -15,18 +15,14 @@ if _found_ESMF:
         print("WARNING: Can not import ESMF for regridding: {0}".format(error))
 
 class Regrid:
-    """
-
-Class containing all the methods required for accessing ESMF
+    """Class containing all the methods required for accessing ESMF
 regridding through ESMPY and the associated utility methods.
 
     """
     
     def __init__(self, srcfield, dstfield, srcfracfield, dstfracfield,
                  method='conservative', ignore_degenerate=False):
-        """
-
-Creates a handle for regridding fields from a source grid to a
+        """Creates a handle for regridding fields from a source grid to a
 destination grid that can then be used by the run_regridding method.
 
 :Parameters:
@@ -51,12 +47,13 @@ destination grid that can then be used by the run_regridding method.
         By default the regridding method is set to 'conservative'. In
         this case first-order conservative regridding is used. If it
         is set to 'bilinear' then multilinear interpolation is used.
-        If it is set to 'nearest_stod' then nearest neighbor
+        If it is set to 'patch' then higher-order patch recovery is
+        used.  If it is set to 'nearest_stod' then nearest neighbor
         interpolation is used where each destination point is mapped
         to the closest source point. A given source point may map to
         multiple destination points, but no destination point will
-        receive input from more than one source point. If it is set
-        to 'nearest_dtos' then nearest neighbor interpolation is used
+        receive input from more than one source point. If it is set to
+        'nearest_dtos' then nearest neighbor interpolation is used
         where each source point is mapped to the closest destination
         point. A given destination point may receive input from
         multiple source points, but no source point will map to more
@@ -71,6 +68,8 @@ destination grid that can then be used by the run_regridding method.
             regrid_method = ESMF.RegridMethod.CONSERVE
         elif method == 'bilinear':
             regrid_method = ESMF.RegridMethod.BILINEAR
+        elif method == 'patch':
+            regrid_method = ESMF.RegridMethod.PATCH
         elif method == 'nearest_stod':
             regrid_method = ESMF.RegridMethod.NEAREST_STOD
         elif method == 'nearest_dtos':
@@ -103,9 +102,7 @@ Free the memory associated with the ESMF.Regrid instance.
     
     @staticmethod
     def initialize():
-        """
-
-Check whether ESMF has been found. If not raise an import
+        """Check whether ESMF has been found. If not raise an import
 error. Initialise the ESMPy manager. Whether logging is enabled or not
 is determined by cf.REGRID_LOGGING. If it is then logging takes place
 after every call to ESMPy.
@@ -126,11 +123,9 @@ after every call to ESMPy.
     @staticmethod
     def create_grid(coords, use_bounds, mask=None, cartesian=False,
                     cyclic=False, coords_2D=False, coord_order=None):
-        """
-
-Create an ESMPy grid given a sequence of coordinates for use as a source
-or destination grid in regridding. Optionally the grid may have an
-associated mask.
+        """Create an ESMPy grid given a sequence of coordinates for use as a
+source or destination grid in regridding. Optionally the grid may have
+an associated mask.
 
 :Parameters:
 
@@ -390,9 +385,7 @@ associated mask.
 
     @staticmethod
     def create_field(grid, name):
-        """
-
-Create an ESMPy field for use as a source or destination field in
+        """Create an ESMPy field for use as a source or destination field in
 regridding given an ESMPy grid and a name.
 
 :Parameters:
@@ -422,9 +415,7 @@ regridding given an ESMPy grid and a name.
     
     @staticmethod
     def concatenate_data(data_list, axis):
-        """
-
-Concatenates a list of Data objects into a single Data object along
+        """Concatenates a list of Data objects into a single Data object along
 the specified access (see cf.Data.concatenate for details). In the
 case that the list contains only one element, that element is simply
 returned.
@@ -456,9 +447,7 @@ returned.
     
     @staticmethod
     def reconstruct_sectioned_data(sections):
-        """
-
-Expects a dictionary of Data objects with ordering information as
+        """Expects a dictionary of Data objects with ordering information as
 keys, as output by the section method when called with a Data
 object. Returns a reconstructed cf.Data object with the sections in
 the original order.
@@ -512,9 +501,7 @@ the original order.
     @staticmethod
     def compute_mass_grid(valuefield, areafield, dofrac=False, fracfield=None, 
                       uninitval=422397696.):
-        '''
-
-Compute the mass of a data field.
+        '''Compute the mass of a data field.
 
 :Parameters:
 
