@@ -15,7 +15,7 @@ class aggregateTest(unittest.TestCase):
         for chunksize in self.chunk_sizes:    
             cf.CHUNKSIZE(chunksize)
 
-            f = cf.read1(self.filename, squeeze=True)
+            f = cf.read(self.filename, squeeze=True)[0]
             f.aux('aux0').id = 'atmosphere_hybrid_height_coordinate_ak'
             f.aux('aux1').id = 'atmosphere_hybrid_height_coordinate_bk'
         
